# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .consent_store import *
from .consent_store_iam_binding import *
from .consent_store_iam_member import *
from .consent_store_iam_policy import *
from .dataset import *
from .dataset_iam_binding import *
from .dataset_iam_member import *
from .dataset_iam_policy import *
from .dicom_store import *
from .dicom_store_iam_binding import *
from .dicom_store_iam_member import *
from .dicom_store_iam_policy import *
from .fhir_store import *
from .fhir_store_iam_binding import *
from .fhir_store_iam_member import *
from .fhir_store_iam_policy import *
from .hl7_store import *
from .hl7_store_iam_binding import *
from .hl7_store_iam_member import *
from .hl7_store_iam_policy import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "gcp:healthcare/consentStore:ConsentStore":
                return ConsentStore(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/consentStoreIamBinding:ConsentStoreIamBinding":
                return ConsentStoreIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/consentStoreIamMember:ConsentStoreIamMember":
                return ConsentStoreIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/consentStoreIamPolicy:ConsentStoreIamPolicy":
                return ConsentStoreIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/dataset:Dataset":
                return Dataset(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/datasetIamBinding:DatasetIamBinding":
                return DatasetIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/datasetIamMember:DatasetIamMember":
                return DatasetIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/datasetIamPolicy:DatasetIamPolicy":
                return DatasetIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/dicomStore:DicomStore":
                return DicomStore(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/dicomStoreIamBinding:DicomStoreIamBinding":
                return DicomStoreIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/dicomStoreIamMember:DicomStoreIamMember":
                return DicomStoreIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/dicomStoreIamPolicy:DicomStoreIamPolicy":
                return DicomStoreIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/fhirStore:FhirStore":
                return FhirStore(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/fhirStoreIamBinding:FhirStoreIamBinding":
                return FhirStoreIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/fhirStoreIamMember:FhirStoreIamMember":
                return FhirStoreIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/fhirStoreIamPolicy:FhirStoreIamPolicy":
                return FhirStoreIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/hl7Store:Hl7Store":
                return Hl7Store(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/hl7StoreIamBinding:Hl7StoreIamBinding":
                return Hl7StoreIamBinding(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/hl7StoreIamMember:Hl7StoreIamMember":
                return Hl7StoreIamMember(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "gcp:healthcare/hl7StoreIamPolicy:Hl7StoreIamPolicy":
                return Hl7StoreIamPolicy(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("gcp", "healthcare/consentStore", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/consentStoreIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/consentStoreIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/consentStoreIamPolicy", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/dataset", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/datasetIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/datasetIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/datasetIamPolicy", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/dicomStore", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/dicomStoreIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/dicomStoreIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/dicomStoreIamPolicy", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/fhirStore", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/fhirStoreIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/fhirStoreIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/fhirStoreIamPolicy", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/hl7Store", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/hl7StoreIamBinding", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/hl7StoreIamMember", _module_instance)
    pulumi.runtime.register_resource_module("gcp", "healthcare/hl7StoreIamPolicy", _module_instance)

_register_module()
