# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'ProviderBatching',
]

@pulumi.output_type
class ProviderBatching(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "enableBatching":
            suggest = "enable_batching"
        elif key == "sendAfter":
            suggest = "send_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProviderBatching. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProviderBatching.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProviderBatching.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enable_batching: Optional[bool] = None,
                 send_after: Optional[str] = None):
        if enable_batching is not None:
            pulumi.set(__self__, "enable_batching", enable_batching)
        if send_after is not None:
            pulumi.set(__self__, "send_after", send_after)

    @property
    @pulumi.getter(name="enableBatching")
    def enable_batching(self) -> Optional[bool]:
        return pulumi.get(self, "enable_batching")

    @property
    @pulumi.getter(name="sendAfter")
    def send_after(self) -> Optional[str]:
        return pulumi.get(self, "send_after")


